@@ -27,7 +27,7 @@ PROJECT_TEMPLATE_DIRS = ['project/templates',]
 
 #context processors
 PROJECT_TEMPLATE_CONTEXT_PROCESSORS = [
-    'backstage.project.utils.context_processors.settings_constants',
+    'backstage.utils.context_processors.settings_constants',
 ]
 
 #automatically convert spaces to underscores
